%% Reproduce results of pFISTA-parallel in the follwing paper:
%% Tianyu Qiu  et al., An Automatic Denoising Method for NMR Spectroscopy Based on Low-Rank Hankel Model, IEEE Transactions on Instrumentation & Measurement, 70: 1-12, 2021.
%% Created by Tianyu Qiu
%% Corresponding Author: Xiaobo Qu
%% Homepage: http://csrc.xmu.edu.cn
%% Email: quxiaobo <|at|> xmu.edu.cn
%% Affiliations: Computational Sensing Group (CSG), Departments of Electronic Science, Xiamen University, Xiamen 361005, China
%% All rights are reserved by CSG.
%% 2021-09
%%
%% Note: The codes were tested on Linux (MATLAB 2017b) platforms.

clear;
close all;
%%
currentFolder = pwd;
addpath(genpath(currentFolder));
%% simulated data
load FID1D_Info
%%
FID = ifft2c(spectra);
FID = FID./max(abs(FID));
%% Add noise
noiseSTD = 0.04;
noise = noiseSTD*(randn(size(FID))+1i*randn(size(FID)));
FID_noisy = FID+noise;
%% Set parameters
params = [];
%% Chord
FID_rec_Chord = solver_Chord_integ(FID_noisy,params); 
%% Plot Fig.2
spec_norm = real(spectra)./max(real(spectra));
spectra_noisy = fft2c(FID_noisy);
figure(1)
% ------------------------------Ground truth----------------------------------
subplot(2,3,1),plot(real(spectra)./max(real(spectra)));ylim([-0.3,1]),xlim([0 numel(spectra)]);title('Ground truth');
% ------------------------------Observation-------------------------------------
subplot(2,3,2),plot(real(spectra_noisy)./max(real(spectra_noisy)));ylim([-0.3,1]),xlim([0 numel(spectra)]);title('Noisy signal');
% ------------------------------CHORD---------------------------------------
FID_rec_LR = FID_rec_Chord;
spec_rec_Chord = real(fft2c(FID_rec_LR));
spectra_Chord = spec_rec_Chord./max(spec_rec_Chord(:));
ADE_CH = sum(abs(spectra_Chord-spec_norm))/length(spec_norm)*ones(size(spec_norm));
subplot(2,3,5),plot(spectra_Chord);ylim([-0.3,1]),xlim([0 numel(spectra)]);title('Chord');


